@@ -1,8 +1,8 @@
-from .dashdevice import dashDevice
-from .tcpconnection import tcpConnection
-from .mqttconnection import mqttConnection
-from .zmqconnection import zmqConnection
-from .dashconnection import dashConnection
+from .dashdevice import DashDevice
+from .tcpconnection import TCPConnection
+from .mqttconnection import MQTTConnection
+from .zmqconnection import ZMQConnection
+from .dashconnection import DashConnection
 from .iotcontrol.enums import (
     Color,
     Icon,
@@ -38,6 +38,6 @@ from .iotcontrol.menu import Menu
 from .iotcontrol.selector import Selector
 from .iotcontrol.label import Label
 from .iotcontrol.page import Page
-from .iotcontrol.control import ControlPosition
+from .iotcontrol.control import Control, ControlPosition
 from .iotcontrol.button_group import ButtonGroup
 from .iotcontrol.event_log import EventData, EventLog
