@@ -1,5 +1,5 @@
-from .enums import Color, LabelStyle, TitlePosition
 from .control import Control
+from .enums import Color, LabelStyle, TitlePosition
 
 
 class Label(Control):
@@ -35,4 +35,4 @@ class Label(Control):
     @color.setter
     def color(self, val: Color):
         self._color = val
-        self._cfg["Color"] = str(val.value)
+        self._cfg["color"] = str(val.value)
